package com.ruixuan.isc.service;

import com.ruixuan.isc.entity.KuaishouRuleDetail;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2023-05-15
 */
public interface IKuaishouRuleDetailService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public KuaishouRuleDetail selectKuaishouRuleDetailById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param kuaishouRuleDetail 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<KuaishouRuleDetail> selectKuaishouRuleDetailList(KuaishouRuleDetail kuaishouRuleDetail);

    /**
     * 新增【请填写功能名称】
     *
     * @param kuaishouRuleDetail 【请填写功能名称】
     * @return 结果
     */
    public int insertKuaishouRuleDetail(KuaishouRuleDetail kuaishouRuleDetail);

    /**
     * 修改【请填写功能名称】
     *
     * @param kuaishouRuleDetail 【请填写功能名称】
     * @return 结果
     */
    public int updateKuaishouRuleDetail(KuaishouRuleDetail kuaishouRuleDetail);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteKuaishouRuleDetailByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteKuaishouRuleDetailById(Long id);
}
